@@ -56,15 +56,15 @@ struct kpMainWindowPrivate
 {
   kpMainWindowPrivate ()
     : isFullyConstructed(false),
-      scrollView(0),
-      mainView(0),
-      thumbnail(0),
-      thumbnailView(0),
-      document(0),
-      viewManager(0),
-      colorToolBar(0),
-      toolToolBar(0),
-      commandHistory(0),
+      scrollView(nullptr),
+      mainView(nullptr),
+      thumbnail(nullptr),
+      thumbnailView(nullptr),
+      document(nullptr),
+      viewManager(nullptr),
+      colorToolBar(nullptr),
+      toolToolBar(nullptr),
+      commandHistory(nullptr),
 
       configFirstTime(false),
       configShowGrid(false),
@@ -72,40 +72,40 @@ struct kpMainWindowPrivate
       configThumbnailShown(false),
       configZoomedThumbnail(false),
 
-      documentEnvironment(0),
-      commandEnvironment(0),
+      documentEnvironment(nullptr),
+      commandEnvironment(nullptr),
 
       // Tools
 
-      toolSelectionEnvironment(0),
-      toolsActionGroup(0),
+      toolSelectionEnvironment(nullptr),
+      toolsActionGroup(nullptr),
 
-      toolSpraycan(0),
-      toolBrush(0),
-      toolColorEraser(0),
-      toolColorPicker(0),
-      toolCurve(0),
-      toolEllipse(0),
-      toolEllipticalSelection(0),
-      toolEraser(0),
-      toolFloodFill(0),
-      toolFreeFormSelection(0),
-      toolLine(0),
-      toolPen(0),
-      toolPolygon(0),
-      toolPolyline(0),
-      toolRectangle(0),
-      toolRectSelection(0),
-      toolRoundedRectangle(0),
-      toolZoom(0),
-      toolText(0),
+      toolSpraycan(nullptr),
+      toolBrush(nullptr),
+      toolColorEraser(nullptr),
+      toolColorPicker(nullptr),
+      toolCurve(nullptr),
+      toolEllipse(nullptr),
+      toolEllipticalSelection(nullptr),
+      toolEraser(nullptr),
+      toolFloodFill(nullptr),
+      toolFreeFormSelection(nullptr),
+      toolLine(nullptr),
+      toolPen(nullptr),
+      toolPolygon(nullptr),
+      toolPolyline(nullptr),
+      toolRectangle(nullptr),
+      toolRectSelection(nullptr),
+      toolRoundedRectangle(nullptr),
+      toolZoom(nullptr),
+      toolText(nullptr),
 
       lastToolNumber(0),
       toolActionsEnabled(false),
-      actionPrevToolOptionGroup1(0),
-      actionNextToolOptionGroup1(0),
-      actionPrevToolOptionGroup2(0),
-      actionNextToolOptionGroup2(0),
+      actionPrevToolOptionGroup1(nullptr),
+      actionNextToolOptionGroup1(nullptr),
+      actionPrevToolOptionGroup2(nullptr),
+      actionNextToolOptionGroup2(nullptr),
 
       settingImageSelectionTransparency(0),
 
@@ -116,23 +116,23 @@ struct kpMainWindowPrivate
       configOpenImagesInSameWindow(false),
       configPrintImageCenteredOnPage(false),
 
-      actionNew(0),
-      actionOpen(0),
-      actionOpenRecent(0),
-      actionScan(0),
-      actionScreenshot(0),
-      actionProperties(0),
-      actionSave(0),
-      actionSaveAs(0),
-      actionExport(0),
-      actionReload(0),
-      actionPrint(0),
-      actionPrintPreview(0),
-      actionMail(0),
-      actionClose(0),
-      actionQuit(0),
+      actionNew(nullptr),
+      actionOpen(nullptr),
+      actionOpenRecent(nullptr),
+      actionScan(nullptr),
+      actionScreenshot(nullptr),
+      actionProperties(nullptr),
+      actionSave(nullptr),
+      actionSaveAs(nullptr),
+      actionExport(nullptr),
+      actionReload(nullptr),
+      actionPrint(nullptr),
+      actionPrintPreview(nullptr),
+      actionMail(nullptr),
+      actionClose(nullptr),
+      actionQuit(nullptr),
 
-      scanDialog(0),
+      scanDialog(nullptr),
 
       exportFirstTime(false),
 
@@ -140,64 +140,64 @@ struct kpMainWindowPrivate
 
       editMenuDocumentActionsEnabled(false),
 
-      actionUndo(0),
-      actionRedo(0),
-      actionCut(0),
-      actionCopy(0),
-      actionPaste(0),
-      actionPasteInNewWindow(0),
-      actionDelete(0),
-      actionSelectAll(0),
-      actionDeselect(0),
-      actionCopyToFile(0),
-      actionPasteFromFile(0),
+      actionUndo(nullptr),
+      actionRedo(nullptr),
+      actionCut(nullptr),
+      actionCopy(nullptr),
+      actionPaste(nullptr),
+      actionPasteInNewWindow(nullptr),
+      actionDelete(nullptr),
+      actionSelectAll(nullptr),
+      actionDeselect(nullptr),
+      actionCopyToFile(nullptr),
+      actionPasteFromFile(nullptr),
 
       copyToFirstTime(false),
 
       // View Menu
 
       configThumbnailShowRectangle(false),
-      actionShowThumbnailRectangle(0),
+      actionShowThumbnailRectangle(nullptr),
 
       viewMenuDocumentActionsEnabled(false),
 
-      actionActualSize(0),
-      actionFitToPage(0),
-      actionFitToWidth(0),
-      actionFitToHeight(0),
-      actionZoomIn(0),
-      actionZoomOut(0),
-      actionZoom(0),
-      actionShowGrid(0),
-      actionShowThumbnail(0),
-      actionZoomedThumbnail(0),
+      actionActualSize(nullptr),
+      actionFitToPage(nullptr),
+      actionFitToWidth(nullptr),
+      actionFitToHeight(nullptr),
+      actionZoomIn(nullptr),
+      actionZoomOut(nullptr),
+      actionZoom(nullptr),
+      actionShowGrid(nullptr),
+      actionShowThumbnail(nullptr),
+      actionZoomedThumbnail(nullptr),
 
-      thumbnailSaveConfigTimer(0),
+      thumbnailSaveConfigTimer(nullptr),
 
       // Image Menu
 
-      transformDialogEnvironment(0),
+      transformDialogEnvironment(nullptr),
 
       imageMenuDocumentActionsEnabled(false),
 
-      actionResizeScale(0),
-      actionCrop(0),
-      actionAutoCrop(0),
-      actionFlip(0),
-      actionMirror(0),
-      actionRotate(0),
-      actionRotateLeft(0),
-      actionRotateRight(0),
-      actionSkew(0),
-      actionConvertToBlackAndWhite(0),
-      actionConvertToGrayscale(0),
-      actionBlur(0),
-      actionMoreEffects(0),
-      actionInvertColors(0),
-      actionClear(0),
+      actionResizeScale(nullptr),
+      actionCrop(nullptr),
+      actionAutoCrop(nullptr),
+      actionFlip(nullptr),
+      actionMirror(nullptr),
+      actionRotate(nullptr),
+      actionRotateLeft(nullptr),
+      actionRotateRight(nullptr),
+      actionSkew(nullptr),
+      actionConvertToBlackAndWhite(nullptr),
+      actionConvertToGrayscale(nullptr),
+      actionBlur(nullptr),
+      actionMoreEffects(nullptr),
+      actionInvertColors(nullptr),
+      actionClear(nullptr),
 
-      actionDrawOpaque(0),
-      actionDrawColorSimilarity(0),
+      actionDrawOpaque(nullptr),
+      actionDrawColorSimilarity(nullptr),
 
       moreEffectsDialogLastEffect(0),
 
@@ -205,38 +205,38 @@ struct kpMainWindowPrivate
 
       colorMenuDocumentActionsEnabled(false),
 
-      actionColorsDefault(0),
-      actionColorsKDE(0),
-      actionColorsOpen(0),
-      actionColorsReload(0),
-      actionColorsSave(0),
-      actionColorsSaveAs(0),
-      actionColorsAppendRow(0),
-      actionColorsDeleteRow(0),
+      actionColorsDefault(nullptr),
+      actionColorsKDE(nullptr),
+      actionColorsOpen(nullptr),
+      actionColorsReload(nullptr),
+      actionColorsSave(nullptr),
+      actionColorsSaveAs(nullptr),
+      actionColorsAppendRow(nullptr),
+      actionColorsDeleteRow(nullptr),
 
       // Settings Menu
 
-      actionShowPath(0),
-      actionKeyBindings(0),
-      actionConfigureToolbars(0),
-      actionConfigure(0),
-      actionFullScreen(0),
+      actionShowPath(nullptr),
+      actionKeyBindings(nullptr),
+      actionConfigureToolbars(nullptr),
+      actionConfigure(nullptr),
+      actionFullScreen(nullptr),
 
       // Status Bar
 
       statusBarCreated(false),
-      statusBarMessageLabel(0),
+      statusBarMessageLabel(nullptr),
       statusBarShapeLastPointsInitialised(false),
       statusBarShapeLastSizeInitialised(false),
 
       // Text ToolBar
 
-      actionTextFontFamily(0),
-      actionTextFontSize(0),
-      actionTextBold(0),
-      actionTextItalic(0),
-      actionTextUnderline(0),
-      actionTextStrikeThru(0),
+      actionTextFontFamily(nullptr),
+      actionTextFontSize(nullptr),
+      actionTextBold(nullptr),
+      actionTextItalic(nullptr),
+      actionTextUnderline(nullptr),
+      actionTextStrikeThru(nullptr),
       settingTextStyle(0),
       textOldFontSize(0)
   {
